package com.weebkun.speedq_printer;

import android.content.Context;

import androidx.annotation.NonNull;

import com.squareup.moshi.Moshi;

import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** SpeedqPrinterPlugin */
public class SpeedqPrinterPlugin implements FlutterPlugin, MethodCallHandler{
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;
    public final Moshi moshi = new Moshi.Builder().build();

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "speedq_printer");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch(call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "getPairedDevices":
                result.success(moshi.adapter(Device[].class).toJson(BluetoothManager.getPairedDevices()));
                break;
            case "connect":
                BluetoothManager.bindService(context);
                BluetoothManager.connect(((List<String>) call.arguments()).get(0));
                result.success(null);
                break;
            case "print":
                BluetoothManager.printText(((List<String>) call.arguments()).get(0));
                result.success(null);
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
